@@ -9,146 +9,176 @@ from .basic_apis import (GetCollectionArticlesJsonDataApi,
                          GetCollectionSubscribersJsonDataApi)
 from .convert import CollectionUrlToCollectionSlug
 
+__all__ = [
+    "GetCollectionName", "GetCollectionAvatarUrl",
+    "GetCollectionIntroductionText", "GetCollectionIntroductionHtml",
+    "GetCollectionArticlesCount", "GetCollectionSubscribersCount",
+    "GetCollectionArticlesUpdateTime", "GetCollectionInformationUpdateTime",
+    "GetCollectionOwnerInfo", "GetCollectionEditorsInfo",
+    "GetCollectionRecommendedWritersInfo", "GetCollectionSubscribersInfo",
+    "GetCollectionAllBasicData", "GetCollectionAllEditorsInfo",
+    "GetCollectionAllRecommendedWritersInfo",
+    "GetCollectionAllSubscribersInfo", "GetCollectionAllArticlesInfo"
+]
 
-def GetCollectionName(collection_url: str) -> str:
+
+def GetCollectionName(collection_url: str, disable_check: bool = False) -> str:
     """获取专题名称
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
+        disable_check (bool): 禁用参数有效性检查. Defaults to False.
 
     Returns:
         str: 专题名称
     """
-    AssertCollectionUrl(collection_url)
-    AssertCollectionStatusNormal(collection_url)
+    if not disable_check:
+        AssertCollectionUrl(collection_url)
+        AssertCollectionStatusNormal(collection_url)
     json_obj = GetCollectionJsonDataApi(collection_url)
     result = json_obj["title"]
     return result
 
 
-def GetCollectionAvatarUrl(collection_url: str) -> str:
+def GetCollectionAvatarUrl(collection_url: str, disable_check: bool = False) -> str:
     """获取专题头像链接
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
+        disable_check (bool): 禁用参数有效性检查. Defaults to False.
 
     Returns:
         str: 专题头像链接
     """
-    AssertCollectionUrl(collection_url)
-    AssertCollectionStatusNormal(collection_url)
+    if not disable_check:
+        AssertCollectionUrl(collection_url)
+        AssertCollectionStatusNormal(collection_url)
     json_obj = GetCollectionJsonDataApi(collection_url)
     result = json_obj["image"]
     return result
 
 
-def GetCollectionIntroductionText(collection_url: str) -> str:
+def GetCollectionIntroductionText(collection_url: str, disable_check: bool = False) -> str:
     """获取纯文本格式的专题简介
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
+        disable_check (bool): 禁用参数有效性检查. Defaults to False.
 
     Returns:
         str: 纯文本格式的专题简介
     """
-    AssertCollectionUrl(collection_url)
-    AssertCollectionStatusNormal(collection_url)
+    if not disable_check:
+        AssertCollectionUrl(collection_url)
+        AssertCollectionStatusNormal(collection_url)
     json_obj = GetCollectionJsonDataApi(collection_url)
     result = json_obj["content_without_html"]
     return result
 
 
-def GetCollectionIntroductionHtml(collection_url: str) -> str:
+def GetCollectionIntroductionHtml(collection_url: str, disable_check: bool = False) -> str:
     """获取 Html 格式的专题简介
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
+        disable_check (bool): 禁用参数有效性检查. Defaults to False.
 
     Returns:
         str: Html 格式的专题简介
     """
-    AssertCollectionUrl(collection_url)
-    AssertCollectionStatusNormal(collection_url)
+    if not disable_check:
+        AssertCollectionUrl(collection_url)
+        AssertCollectionStatusNormal(collection_url)
     json_obj = GetCollectionJsonDataApi(collection_url)
     result = json_obj["content_in_full"]
     return result
 
 
-def GetCollectionArticlesCount(collection_url: str) -> int:
+def GetCollectionArticlesCount(collection_url: str, disable_check: bool = False) -> int:
     """获取专题中的文章数量
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
+        disable_check (bool): 禁用参数有效性检查. Defaults to False.
 
     Returns:
         int: 专题中的文章数量
     """
-    AssertCollectionUrl(collection_url)
-    AssertCollectionStatusNormal(collection_url)
+    if not disable_check:
+        AssertCollectionUrl(collection_url)
+        AssertCollectionStatusNormal(collection_url)
     json_obj = GetCollectionJsonDataApi(collection_url)
     result = json_obj["notes_count"]
     return result
 
 
-def GetCollectionSubscribersCount(collection_url: str) -> int:
+def GetCollectionSubscribersCount(collection_url: str, disable_check: bool = False) -> int:
     """获取专题的订阅者数量
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
+        disable_check (bool): 禁用参数有效性检查. Defaults to False.
 
     Returns:
         int: 专题的订阅者数量
     """
-    AssertCollectionUrl(collection_url)
-    AssertCollectionStatusNormal(collection_url)
+    if not disable_check:
+        AssertCollectionUrl(collection_url)
+        AssertCollectionStatusNormal(collection_url)
     json_obj = GetCollectionJsonDataApi(collection_url)
     result = json_obj["subscribers_count"]
     return result
 
 
-def GetCollectionArticlesUpdateTime(collection_url: str) -> datetime:
+def GetCollectionArticlesUpdateTime(collection_url: str, disable_check: bool = False) -> datetime:
     """获取专题文章更新时间
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
+        disable_check (bool): 禁用参数有效性检查. Defaults to False.
 
     Returns:
         datetime: 专题文章更新时间
     """
-    AssertCollectionUrl(collection_url)
-    AssertCollectionStatusNormal(collection_url)
+    if not disable_check:
+        AssertCollectionUrl(collection_url)
+        AssertCollectionStatusNormal(collection_url)
     json_obj = GetCollectionJsonDataApi(collection_url)
     result = datetime.fromtimestamp(json_obj["newly_added_at"])
     return result
 
 
-def GetCollectionInformationUpdateTime(collection_url: str) -> datetime:
+def GetCollectionInformationUpdateTime(collection_url: str, disable_check: bool = False) -> datetime:
     """获取专题信息更新时间
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
+        disable_check (bool): 禁用参数有效性检查. Defaults to False.
 
     Returns:
         datetime: 专题信息更新时间
     """
-    AssertCollectionUrl(collection_url)
-    AssertCollectionStatusNormal(collection_url)
+    if not disable_check:
+        AssertCollectionUrl(collection_url)
+        AssertCollectionStatusNormal(collection_url)
     json_obj = GetCollectionJsonDataApi(collection_url)
     result = datetime.fromtimestamp(json_obj["last_updated_at"])
     return result
 
 
-def GetCollectionOwnerInfo(collection_url: str) -> Dict:
+def GetCollectionOwnerInfo(collection_url: str, disable_check: bool = False) -> Dict:
     """获取专题的所有者信息
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
+        disable_check (bool): 禁用参数有效性检查. Defaults to False.
 
     Returns:
         Dict: 用户信息
     """
-    AssertCollectionUrl(collection_url)
-    AssertCollectionStatusNormal(collection_url)
+    if not disable_check:
+        AssertCollectionUrl(collection_url)
+        AssertCollectionStatusNormal(collection_url)
     json_obj = GetCollectionJsonDataApi(collection_url)
     result = {
         "uid": json_obj["owner"]["id"],
@@ -208,7 +238,7 @@ def GetCollectionRecommendedWritersInfo(collection_id: int, page: int = 1, count
 
 
 def GetCollectionSubscribersInfo(collection_id: int, start_sort_id: int = None) -> List[Dict]:
-    """该函数接收一个专题 ID，并返回该 ID 对应专题的关注者信息
+    """获取专题关注者信息
 
     Args:
         collection_id (int): 专题 ID
@@ -232,21 +262,24 @@ def GetCollectionSubscribersInfo(collection_id: int, start_sort_id: int = None)
 
 
 def GetCollectionArticlesInfo(collection_url: str, page: int = 1,
-                              count: int = 10, sorting_method: str = "time") -> List[Dict]:
-    """该函数接收专题 Url ，并返回该 Url 对应专题的文章信息
+                              count: int = 10, sorting_method: str = "time",
+                              disable_check: bool = False) -> List[Dict]:
+    """获取专题文章信息
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
         page (int, optional): 页码. Defaults to 1.
         count (int, optional): 每次返回的数据数量. Defaults to 10.
         sorting_method (str, optional): 排序方法，"time" 为按照发布时间排序，
         "comment_time" 为按照最近评论时间排序，"hot" 为按照热度排序. Defaults to "time".
+        disable_check (bool): 禁用参数有效性检查. Defaults to False.
 
     Returns:
         List[Dict]: 文章信息
     """
-    AssertCollectionUrl(collection_url)
-    AssertCollectionStatusNormal(collection_url)
+    if not disable_check:
+        AssertCollectionUrl(collection_url)
+        AssertCollectionStatusNormal(collection_url)
     order_by = {
         "time": "added_at",
         "comment_time": "commented_at",
@@ -281,15 +314,19 @@ def GetCollectionArticlesInfo(collection_url: str, page: int = 1,
     return result
 
 
-def GetCollectionAllBasicData(collection_url: str) -> Dict:
+def GetCollectionAllBasicData(collection_url: str, disable_check: bool = False) -> Dict:
     """获取专题的所有基础信息
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
+        disable_check (bool): 禁用参数有效性检查. Defaults to False.
 
     Returns:
-        dict: 专题基础信息
+        Dict: 专题基础信息
     """
+    if not disable_check:
+        AssertCollectionUrl(collection_url)
+        AssertCollectionStatusNormal(collection_url)
     result = {}
     json_obj = GetCollectionJsonDataApi(collection_url)
 
@@ -309,82 +346,115 @@ def GetCollectionAllBasicData(collection_url: str) -> Dict:
     return result
 
 
-def GetCollectionAllEditorsInfo(collection_id: int) -> Generator[List[Dict], None, None]:
+def GetCollectionAllEditorsInfo(collection_id: int, max_count: int = None) -> Generator[Dict, None, None]:
     """获取专题的所有编辑信息
 
     Args:
         collection_id (int): 专题 ID
+        max_count (int, optional): 获取的专题编辑信息数量上限，Defaults to None.
 
     Yields:
-        Iterator[List[Dict], None, None]: 当前页编辑信息
+        Iterator[Dict], None, None]: 编辑信息
     """
     page = 1
+    now_count = 0
     while True:
         result = GetCollectionEditorsInfo(collection_id, page)
         if result:
-            yield result
             page += 1
         else:
-            break
+            return
+        for item in result:
+            yield item
+            if max_count:
+                now_count += 1
+                if now_count == max_count:
+                    return
 
 
-def GetCollectionAllRecommendedWritersInfo(collection_id: int, count: int = 20) -> Generator[List[Dict], None, None]:
+def GetCollectionAllRecommendedWritersInfo(collection_id: int, count: int = 20, max_count: int = None) -> Generator[Dict, None, None]:
     """获取专题的所有推荐作者信息
 
     Args:
         collection_id (int): 专题 ID
         count (int, optional): 单次获取的数据数量，会影响性能. Defaults to 20.
+        max_count (int, optional): 获取的专题推荐作者信息数量上限，Defaults to None.
 
     Yields:
-        Iterator[List[Dict], None, None]: 当前页推荐作者信息
+        Iterator[Dict], None, None]: 推荐作者信息
     """
     page = 1
+    now_count = 0
     while True:
         result = GetCollectionRecommendedWritersInfo(collection_id, page, count)
         if result:
-            yield result
             page += 1
         else:
-            break
+            return
+        for item in result:
+            yield item
+            if max_count:
+                now_count += 1
+                if now_count == max_count:
+                    return
 
 
-def GetCollectionAllSubscribersInfo(collection_id: int) -> Generator[List[Dict], None, None]:
+def GetCollectionAllSubscribersInfo(collection_id: int, max_count: int = None) -> Generator[Dict, None, None]:
     """获取专题的所有关注者信息
 
     Args:
         collection_id (int): 专题 ID
+        max_count (int, optional): 获取的专题关注者信息数量上限，Defaults to None.
 
     Yields:
-        Iterator[List[Dict], None, None]: 当前页关注者信息
+        Iterator[Dict], None, None]: 关注者信息
     """
     start_sort_id = None
+    now_count = 0
     while True:
         result = GetCollectionSubscribersInfo(collection_id, start_sort_id)
         if result:
-            yield result
             start_sort_id = result[-1]["sort_id"]
         else:
-            break
+            return
+        for item in result:
+            yield item
+            if max_count:
+                now_count += 1
+                if now_count == max_count:
+                    return
 
 
 def GetCollectionAllArticlesInfo(collection_url: str, count: int = 10,
-                                 sorting_method: str = "time") -> Generator[List[Dict], None, None]:
+                                 sorting_method: str = "time", max_count: int = None,
+                                 disable_check: bool = False) -> Generator[Dict, None, None]:
     """获取专题的所有文章信息
 
     Args:
-        collection_url (str): 专题 Url
+        collection_url (str): 专题 URL
         count (int, optional): 单次获取的数据数量，会影响性能. Defaults to 10.
         sorting_method (str, optional): 排序方法，"time" 为按照发布时间排序，
         "comment_time" 为按照最近评论时间排序，"hot" 为按照热度排序. Defaults to "time".
+        max_count (int, optional): 获取的专题文章信息数量上限，Defaults to None.
+        disable_check (bool): 禁用参数有效性检查. Defaults to False.
 
     Yields:
-        Iterator[List[Dict], None, None]: 当前页文章信息
+        Iterator[Dict], None, None]: 文章信息
     """
+    if not disable_check:
+        AssertCollectionUrl(collection_url)
+        AssertCollectionStatusNormal(collection_url)
     page = 1
+    now_count = 0
     while True:
-        result = GetCollectionArticlesInfo(collection_url, page, count, sorting_method)
+        result = GetCollectionArticlesInfo(collection_url, page, count, sorting_method, disable_check=True)
         if result:
-            yield result
             page += 1
         else:
-            break
+            return
+        for item in result:
+            yield item
+            if max_count:
+                now_count += 1
+                if now_count == max_count:
+                    return
