@@ -1,4 +1,4 @@
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, date
 from typing import Dict, List
 
 from .basic_apis import (GetArticlesFPRankListJsonDataApi,
@@ -67,13 +67,13 @@ def GetDailyArticleRankData() -> List[Dict]:
     return result
 
 
-def GetArticleFPRankData(date: str = "latest") -> List[Dict]:
+def GetArticleFPRankData(target_date: str = "latest") -> List[Dict]:
     """获取文章收益排行榜信息
 
     目前只能获取 2020 年 6 月 20 日之后的数据。
 
     Args:
-        date (str, optional): 日期，格式“YYYYMMDD”. Defaults to "latest".
+        target_date (str, optional): 日期，格式“YYYYMMDD”. Defaults to "latest".
 
     Raises:
         ResourceError: 对应日期的排行榜数据为空时抛出此异常
@@ -81,9 +81,9 @@ def GetArticleFPRankData(date: str = "latest") -> List[Dict]:
     Returns:
         List[Dict]: 文章收益排行榜信息
     """
-    if date == "latest":
-        date = (datetime.today() + timedelta(days=-1)).strftime(r"%Y%m%d")
-    json_obj = GetArticlesFPRankListJsonDataApi(date=date, type_=None)
+    if target_date == "latest":
+        target_date = (datetime.today() + timedelta(days=-1)).strftime(r"%Y%m%d")
+    json_obj = GetArticlesFPRankListJsonDataApi(date=target_date, type_=None)
     if json_obj["notes"] == []:
         raise ResourceError(f"对应日期 {date} 的排行榜数据为空")
     result = []
@@ -102,13 +102,13 @@ def GetArticleFPRankData(date: str = "latest") -> List[Dict]:
     return result
 
 
-def GetArticleFPRankBasicInfo(date: str = "latest") -> Dict:
+def GetArticleFPRankBasicInfo(target_date: str = "latest") -> Dict:
     """获取文章收益排行榜信息
 
     目前只能获取 2020 年 6 月 20 日之后的数据。
 
     Args:
-        date (str, optional): 日期，格式“YYYYMMDD”. Defaults to "latest".
+        target_date (str, optional): 日期，格式“YYYYMMDD”. Defaults to "latest".
 
     Raises:
         ResourceError: 对应日期的排行榜数据为空时抛出此异常
@@ -116,11 +116,11 @@ def GetArticleFPRankBasicInfo(date: str = "latest") -> Dict:
     Returns:
         Dict: 文章收益排行榜基础信息
     """
-    if date == "latest":
-        date = (datetime.date.today() + datetime.timedelta(days=-1)).strftime("%Y%m%d")
-    json_obj = GetArticlesFPRankListJsonDataApi(date=date, type_=None)
+    if target_date == "latest":
+        target_date = (date.today() + timedelta(days=-1)).strftime("%Y%m%d")
+    json_obj = GetArticlesFPRankListJsonDataApi(date=target_date, type_=None)
     if json_obj["notes"] == []:
-        raise ResourceError(f"对应日期 {date} 的排行榜数据为空")
+        raise ResourceError(f"对应日期 {target_date} 的排行榜数据为空")
     result = {
         "total_fp": json_obj["fp"],
         "fp_to_author": json_obj["author_fp"],
@@ -129,13 +129,14 @@ def GetArticleFPRankBasicInfo(date: str = "latest") -> Dict:
     return result
 
 
-def GetUserFPRankData(date: str = "latest", rank_type: str = "all") -> List[Dict]:
+def GetUserFPRankData(target_date: str = "latest", rank_type: str = "all") -> List[Dict]:
     """获取用户收益排行榜信息
 
     目前只能获取 2020 年 6 月 20 日之后的数据。
 
     Args:
-        date (str, optional): 日期，格式“YYYYMMDD”. Defaults to "latest".
+        target_date (str, optional): 日期，格式“YYYYMMDD”. Defaults to "latest".
+        rank_type (str, optional): 排行榜分类，"all" 为总收益榜，"write" 为内容收益榜，"vote" 为投票收益榜
 
     Raises:
         ResourceError: 对应日期的排行榜数据为空时抛出此异常
@@ -148,9 +149,9 @@ def GetUserFPRankData(date: str = "latest", rank_type: str = "all") -> List[Dict
         "write": "note",
         "vote": "like"
     }[rank_type]
-    json_obj = GetArticlesFPRankListJsonDataApi(date=date, type_=type_)
+    json_obj = GetArticlesFPRankListJsonDataApi(date=target_date, type_=type_)
     if json_obj["users"] == []:
-        raise ResourceError(f"对应日期 {date} 的排行榜数据为空")
+        raise ResourceError(f"对应日期 {target_date} 的排行榜数据为空")
     result = []
     for ranking, item in enumerate(json_obj["users"]):
         item_data = {
